searchData={"items":[{"type":"module","title":"Nip.Pns","doc":"Functions for working with NIP PNS (Nomor Induk Pegawai Negeri Sipil)\n\nNIP PNS consists of 18 digits that divided into 4 parts:\n- `8` digits for birth date (`YYYYMMDD`)\n- `6` digits for TMT (Tanggal Mulai Tugas) (`YYYYMM`)\n- `1` digit for sex code (`1` for male and `2` for female)\n- `3` digits for serial number (`001-999`)","ref":"Nip.Pns.html"},{"type":"function","title":"Nip.Pns.parse/1","doc":"Parse NIP PNS into a struct.\n\nThis function returns `{:ok, %Nip.Pns{}}` if the NIP is valid, otherwise `{:error, reason}`.","ref":"Nip.Pns.html#parse/1"},{"type":"function","title":"Examples - Nip.Pns.parse/1","doc":"iex> Nip.Pns.parse(\"200012312024121001\")\n    {:ok,\n    %Nip.Pns{\n      nip: \"200012312024121001\",\n      birth_date: ~D[2000-12-31],\n      tmt_date: ~D[2024-12-01],\n      sex: \"M\",\n      serial_number: \"001\"\n    }}","ref":"Nip.Pns.html#parse/1-examples"},{"type":"function","title":"Nip.Pns.validate_format/1","doc":"Validate NIP format.\n\nThis function returns `{:ok, nip}` if the NIP is valid, otherwise `{:error, reason}`.","ref":"Nip.Pns.html#validate_format/1"},{"type":"function","title":"Examples - Nip.Pns.validate_format/1","doc":"iex> Nip.Pns.validate_format(\"200012312024121001\")\n    {:ok, \"200012312024121001\"}","ref":"Nip.Pns.html#validate_format/1-examples"},{"type":"module","title":"Nip.Pppk","doc":"Functions for working with NIP PPPK (Pegawai Pemerintah dengan Perjanjian Kerja)\n\nNIP PNS consists of 18 digits that divided into 4 parts:\n- `8` digits for birth date (`YYYYMMDD`)\n- `4` digits for TMT (Tanggal Mulai Tugas) (`YYYY`)\n- `1` digit that indicates the code for PPPK (`2`)\n- `1` digit for frequency (`1-9`)\n- `1` digit for sex code (`1` for male and `2` for female)\n- `3` digits for serial number (`001-999`)","ref":"Nip.Pppk.html"},{"type":"function","title":"Nip.Pppk.parse/1","doc":"Parse NIP PPPK into a struct.\n\nThis function returns `{:ok, %Nip.Pppk{}}` if the NIP is valid, otherwise `{:error, reason}`.","ref":"Nip.Pppk.html#parse/1"},{"type":"function","title":"Examples - Nip.Pppk.parse/1","doc":"iex> Nip.Pppk.parse(\"200012312024211001\")\n    {:ok,\n    %Nip.Pppk{\n      nip: \"200012312024211001\",\n      birth_date: ~D[2000-12-31],\n      tmt_date: ~D[2024-01-01],\n      frequency: 1,\n      sex: \"M\",\n      serial_number: \"001\"\n    }}","ref":"Nip.Pppk.html#parse/1-examples"},{"type":"function","title":"Nip.Pppk.validate_format/1","doc":"Validate NIP format.\n\nThis function returns `{:ok, nip}` if the NIP is valid, otherwise `{:error, reason}`.","ref":"Nip.Pppk.html#validate_format/1"},{"type":"function","title":"Examples - Nip.Pppk.validate_format/1","doc":"iex> Nip.Pppk.validate_format(\"200012312024211001\")\n    {:ok, \"200012312024211001\"}","ref":"Nip.Pppk.html#validate_format/1-examples"},{"type":"extras","title":"indonesian_id","doc":"# indonesian_id\n\n![Hex.pm Version](https://img.shields.io/hexpm/v/indonesian_id) ![Hex.pm Downloads](https://img.shields.io/hexpm/dt/indonesian_id) [![Elixir CI](https://github.com/muzhawir/indonesian_id/actions/workflows/elixir.yml/badge.svg?branch=main)](https://github.com/muzhawir/indonesian_id/actions/workflows/elixir.yml)\n\nA package for parsing and validating Indonesian identification numbers. This library provides\nfunctions to ensure the format and validity of these IDs, making it easier to handle Indonesian\nidentification numbers in your Elixir applications.","ref":"readme.html"},{"type":"extras","title":"Installation - indonesian_id","doc":"The package is [available in Hex](https://hex.pm/packages/indonesian_id) and can be installed\nby adding `indonesian_id` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:indonesian_id, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}